Commit 5ef8eb49be25f5b751fe6cb018c9dc62bdf615b0

Sam Lantinga 2018-08-29T20:55:02

Don't show the Razer Raiju sound interface as a game controller

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
diff --git a/src/joystick/hidapi/SDL_hidapi_ps4.c b/src/joystick/hidapi/SDL_hidapi_ps4.c
index 6dcdb64..ffef968 100644
--- a/src/joystick/hidapi/SDL_hidapi_ps4.c
+++ b/src/joystick/hidapi/SDL_hidapi_ps4.c
@@ -216,9 +216,11 @@ static uint8_t GetPlaystationVolumeFromFloat(float fVolume)
 static SDL_bool
 HIDAPI_DriverPS4_IsSupportedDevice(Uint16 vendor_id, Uint16 product_id, Uint16 version, int interface_number, Uint16 usage_page, Uint16 usage)
 {
     /* The Revolution Pro Controller exposes multiple interfaces on Windows */
     const Uint16 NACON_USB_VID = 0x146b;
-    if (vendor_id == NACON_USB_VID && usage_page != 0 && usage_page != 1) {
+    const Uint16 RAZER_USB_VID = 0x1532;
+    if ((vendor_id == NACON_USB_VID || vendor_id == RAZER_USB_VID) &&
+        (usage_page != 0 && usage_page != 1)) {
         return SDL_FALSE;
     }
@@ -216,9 +216,11 @@ static uint8_t GetPlaystationVolumeFromFloat(float fVolume)
 HIDAPI_DriverPS4_IsSupportedDevice(Uint16 vendor_id, Uint16 product_id, Uint16 version, int interface_number, Uint16 usage_page, Uint16 usage)
 {
-    /* The Revolution Pro Controller exposes multiple interfaces on Windows */
+    /* The Revolution Pro Controller and Razer Raiju expose multiple interfaces on Windows */
     const Uint16 NACON_USB_VID = 0x146b;